ToIOPattern

Trait ToIOPattern 

pub trait ToIOPattern {
    // Required method
    fn to_iopattern() -> IOPattern;
}
Conversion from a trait::List type-level IOPattern to a crate::IOpattern This is morally an extension trait of the List trait, though Rust can of course not check exhaustivity.

Required Methods

fn to_iopattern() -> IOPattern

Converts the type-level pattern to its term-level representation

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors